@@ -7,11 +7,18 @@ import sys
 import warnings
 import re
 
+import os
+try:
+    from subprocess import DEVNULL  # py3k
+except ImportError:
+    DEVNULL = open(os.devnull, 'wb')
+
+
 def sys_write_flush(s):
     """ Writes and flushes without delay a text in the console """
     sys.stdout.write(s)
     sys.stdout.flush()
-    
+
 
 def verbose_print(verbose, s):
     """ Only prints s (with sys_write_flush) if verbose is True."""
@@ -23,18 +30,25 @@ def subprocess_call(cmd, verbose=True, errorprint=True):
     """ Executes the given subprocess command."""
 
     verbose_print(verbose, "\nMoviePy Running:\n>>> "+ " ".join(cmd))
-    
-    proc = sp.Popen(cmd, stderr = sp.PIPE)
-                         
+
+    popen_params = {"stdout": DEVNULL,
+                    "stderr": sp.PIPE,
+                    "stdin": DEVNULL}
+
+    if os.name == "nt":
+        popen_params["creationflags"] = 0x08000000
+
+    proc = sp.Popen(cmd, **popen_params)
+
     out, err = proc.communicate() # proc.wait()
     proc.stderr.close()
-    
+
     if proc.returncode:
         verbose_print(errorprint, "\nMoviePy: This command returned an error !")
         raise IOError(err.decode('utf8'))
     else:
         verbose_print(verbose, "\n... command successful.\n")
-    
+
     del proc
 
 def is_string(obj):
@@ -48,7 +62,7 @@ def is_string(obj):
 def cvsecs(time):
     """ Will convert any time into seconds.
     Here are the accepted formats:
-    
+
     >>> cvsecs(15.4) -> 15.4 # seconds
     >>> cvsecs( (1,21.5) ) -> 81.5 # (min,sec)
     >>> cvsecs( (1,1,2) ) -> 3662 # (hr, min, sec)
@@ -67,35 +81,35 @@ def cvsecs(time):
                 + 60*int(finds[1])
                 + int(finds[2])
                 + nums[3]/(10**len(finds[3])))
-    
+
     elif isinstance(time, tuple):
         if len(time)== 3:
             hr, mn, sec = time
         elif len(time)== 2:
-            hr, mn, sec = 0, time[0], time[1]    
+            hr, mn, sec = 0, time[0], time[1]
         return 3600*hr + 60*mn + sec
-    
+
     else:
         return time
 
 def deprecated_version_of(f, oldname, newname=None):
     """ Indicates that a function is deprecated and has a new name.
-    
+
     `f` is the new function, `oldname` the name of the deprecated
     function, `newname` the name of `f`, which can be automatically
     found.
-    
+
     Returns
     ========
-    
+
     f_deprecated
       A function that does the same thing as f, but with a docstring
       and a printed message on call which say that the function is
       deprecated and that you should use f instead.
-    
+
     Examples
     =========
-    
+
     >>> # The badly named method 'to_file' is replaced by 'write_file'
     >>> class Clip:
     >>>    def write_file(self, some args):
@@ -103,18 +117,18 @@ def deprecated_version_of(f, oldname, newname=None):
     >>>
     >>> Clip.to_file = deprecated_version_of(Clip.write_file, 'to_file')
     """
-    
+
     if newname is None: newname = f.__name__
-    
+
     warning= ("The function ``%s`` is deprecated and is kept temporarily "
               "for backwards compatibility.\nPlease use the new name, "
               "``%s``, instead.")%(oldname, newname)
-    
+
     def fdepr(*a, **kw):
         warnings.warn("MoviePy: " + warning, PendingDeprecationWarning)
         return f(*a, **kw)
     fdepr.__doc__ = warning
-    
+
     return fdepr
 
 
@@ -126,7 +140,7 @@ def deprecated_version_of(f, oldname, newname=None):
 extensions_dict = { "mp4":  {'type':'video', 'codec':['libx264','libmpeg4']},
                     'ogv':  {'type':'video', 'codec':['libtheora']},
                     'webm': {'type':'video', 'codec':['libvpx']},
-                    'avi':  {'type':'video'}, 
+                    'avi':  {'type':'video'},
                     'mov':  {'type':'video'},
 
                     'ogg':  {'type':'audio', 'codec':['libvorbis']},
