@@ -1,7 +1,6 @@
 from moviepy.decorators import apply_to_mask,apply_to_audio
 
-@apply_to_mask
-@apply_to_audio
+
 def speedx(clip, factor = None, final_duration=None):
     """
     Returns a clip playing the current clip but at a speed multiplied
@@ -14,7 +13,7 @@ def speedx(clip, factor = None, final_duration=None):
     if final_duration:
         factor = 1.0* clip.duration / final_duration
         
-    newclip = clip.fl_time(lambda t: factor * t)
+    newclip = clip.fl_time(lambda t: factor * t, apply_to=['mask', 'audio'])
     
     if clip.duration != None:
         newclip = newclip.set_duration(1.0 * clip.duration / factor)
