@@ -1,15 +1,14 @@
 import os
 import subprocess as sp
 from tqdm import tqdm
-from moviepy.conf import FFMPEG_BINARY, IMAGEMAGICK_BINARY
+from moviepy.config import get_setting
 from moviepy.decorators import requires_duration
 from moviepy.tools import verbose_print, subprocess_call
 import numpy as np
 
 try:
-    from subprocess import DEVNULL # py3k
+    from subprocess import DEVNULL  # py3k
 except ImportError:
-    import os
     DEVNULL = open(os.devnull, 'wb')
 
 
@@ -53,7 +52,7 @@ def write_gif_with_tempfiles(clip, filename, fps=None, program= 'ImageMagick',
 
     if program == "ImageMagick":
 
-        cmd = [IMAGEMAGICK_BINARY,
+        cmd = [get_setting("IMAGEMAGICK_BINARY"),
               '-delay' , '%d'%delay,
               "-dispose" ,"%d"%(2 if dispose else 1),
               "-loop" , "%d"%loop,
@@ -66,7 +65,7 @@ def write_gif_with_tempfiles(clip, filename, fps=None, program= 'ImageMagick',
 
     elif program == "ffmpeg":
 
-        cmd = [FFMPEG_BINARY, '-y',
+        cmd = [get_setting("FFMPEG_BINARY"), '-y',
                '-f', 'image2', '-r',str(fps),
                '-i', fileName+'_GIFTEMP%04d.png',
                '-r',str(fps),
@@ -75,17 +74,17 @@ def write_gif_with_tempfiles(clip, filename, fps=None, program= 'ImageMagick',
     try:
         subprocess_call( cmd, verbose = verbose )
 
-    except IOError as err:
+    except (IOError,OSError) as err:
 
         error = ("MoviePy Error: creation of %s failed because "
           "of the following error:\n\n%s.\n\n."%(filename, str(err)))
-        
+
         if program == "ImageMagick":
-            error = error + ("This can be due to the fact that "
+            error = error + ("This error can be due to the fact that "
                 "ImageMagick is not installed on your computer, or "
                 "(for Windows users) that you didn't specify the "
                 "path to the ImageMagick binary in file conf.py." )
-        
+
         raise IOError(error)
 
     for f in tempfiles:
@@ -149,7 +148,7 @@ def write_gif(clip, filename, fps=None, program= 'ImageMagick',
     # if program == 'ImageMagick' and optimize == (None, False)
     # frames --ffmpeg--> bmp frames --ImageMagick--> gif
     #
-    # 
+    #
     # if program == 'ImageMagick' and optimize != (None, False)
     # frames -ffmpeg-> bmp frames -ImagMag-> gif -ImagMag-> better gif
     #
@@ -158,40 +157,59 @@ def write_gif(clip, filename, fps=None, program= 'ImageMagick',
         fps=clip.fps
     delay= 100.0/fps
 
-    cmd1 = [FFMPEG_BINARY, '-y', '-loglevel', 'error',
+    cmd1 = [get_setting("FFMPEG_BINARY"), '-y', '-loglevel', 'error',
             '-f', 'rawvideo',
             '-vcodec','rawvideo', '-r', "%.02f"%fps,
             '-s', "%dx%d"%(clip.w, clip.h), '-pix_fmt', 'rgb24',
             '-i', '-']
 
+    popen_params = {"stdout": DEVNULL,
+                    "stderr": DEVNULL,
+                    "stdin": DEVNULL}
+
+    if os.name == "nt":
+        popen_params["creationflags"] = 0x08000000
+
     if program == "ffmpeg":
-        proc1 = sp.Popen(cmd1+['-r', "%.02f"%fps, filename],
-                         stdin=sp.PIPE, stdout=DEVNULL)
+        popen_params["stdin"] = sp.PIPE
+        popen_params["stdout"] = DEVNULL
+
+        proc1 = sp.Popen(cmd1+['-r', "%.02f"%fps, filename], **popen_params)
     else:
+
+        popen_params["stdin"] = sp.PIPE
+        popen_params["stdout"] = sp.PIPE
+
         proc1 = sp.Popen(cmd1+['-f', 'image2pipe',
                                '-vcodec', 'bmp', '-'],
-                         stdin=sp.PIPE, stdout=sp.PIPE)
+                         **popen_params)
 
     if program == 'ImageMagick':
-        
-        cmd2 = [IMAGEMAGICK_BINARY, '-delay', "%.02f"%(delay),
+
+        cmd2 = [get_setting("IMAGEMAGICK_BINARY"), '-delay', "%.02f"%(delay),
                 "-dispose" ,"%d"%(2 if dispose else 1),
                 '-loop', '%d'%loop, '-', '-coalesce']
-        
+
         if (opt in [False, None]):
-            proc2 = sp.Popen(cmd2+[filename], stdin=proc1.stdout)
-            
+            popen_params["stdin"] = proc1.stdout
+            popen_params["stdout"] = DEVNULL
+            proc2 = sp.Popen(cmd2+[filename], **popen_params)
+
         else:
-            proc2 = sp.Popen(cmd2+['gif:-'] , stdin=proc1.stdout,
-                             stdout=sp.PIPE)
-            
+            popen_params["stdin"] = proc1.stdout
+            popen_params["stdout"] = sp.PIPE
+            proc2 = sp.Popen(cmd2+['gif:-'], **popen_params)
+
         if opt:
-            
-            cmd3 = [IMAGEMAGICK_BINARY, '-', '-layers', opt,
+
+            cmd3 = [get_setting("IMAGEMAGICK_BINARY"), '-', '-layers', opt,
                     '-fuzz', '%d'%fuzz+'%'
                    ]+(["-colors", "%d"%colors] if colors is not None else [])+[
                    filename]
-            proc3 = sp.Popen(cmd3, stdin=proc2.stdout)
+
+            popen_params["stdin"] = proc2.stdout
+            popen_params["stdout"] = DEVNULL
+            proc3 = sp.Popen(cmd3, **popen_params)
 
     # We send all the frames to the first process
     verbose_print(verbose, "\nMoviePy: building GIF file %s\n"%filename
@@ -208,13 +226,13 @@ def write_gif(clip, filename, fps=None, program= 'ImageMagick',
 
         error = ("MoviePy Error: creation of %s failed because "
           "of the following error:\n\n%s.\n\n."%(filename, str(err)))
-        
+
         if program == "ImageMagick":
             error = error + ("This can be due to the fact that "
                 "ImageMagick is not installed on your computer, or "
                 "(for Windows users) that you didn't specify the "
                 "path to the ImageMagick binary in file conf.py." )
-        
+
         raise IOError(error)
     verbose_print(verbose, "Writing GIF... ")
     proc1.stdin.close()
